@@ -395,13 +395,14 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
                 curs = self.textCursor()
                 spos = curs.positionInBlock()
                 count = 0
-                while curs.block().text()[spos-count-1:spos-count] == ' ':
-                    count += 1
-                if spos-count == 0:
-                    count = 4 if count % 4 == 0 else count % 4
-                    for i in range(count):
-                        curs.deletePreviousChar()
-                    return
+                if spos > 0:
+                    while curs.block().text()[spos-count-1:spos-count] == ' ':
+                        count += 1
+                    if spos-count == 0:
+                        count = 4 if count % 4 == 0 else count % 4
+                        for i in range(count):
+                            curs.deletePreviousChar()
+                        return
         
         if self.completer:
             if self.completer.popup().isVisible():
