@@ -23,7 +23,9 @@ def connect(name=None, user=None, pwd=None):
     global db
     if name is None:
         home = os.getenv('HOME') if os.getenv('HOME') else os.getenv('USERPROFILE')
-        localSettingsFile = os.path.join(home, 'mangrove1.0', 'settings.info')
+        localSettingsFile = os.getenv('MGVSETTINGS')
+        if localSettingsFile is None:
+            localSettingsFile = os.path.join(home, 'mangrove1.0', 'settings.info')
         name, user, pwd = '', '', ''
         if os.path.exists(localSettingsFile):
             with open(localSettingsFile) as fid:
@@ -91,7 +93,8 @@ def getType(project_name, name=None, uuid=None):
         gt = db[project_name].find_one({'code': 'Type', 'parent': pid, '_id': uuid})
     if name:
         gt = db[project_name].find_one({'code': 'Type', 'parent': pid, 'name': name})
-
+    if gt is None:
+        return None
     typeFiles = []
     for gf in db[project_name].find({'code': 'TypeFile', 'parent': gt['_id']}):
         typeFiles.append(mgvApi.MgvTypeFile(uuid=gf['_id'], name=gf['name'], path=gf['path'],
@@ -448,20 +451,23 @@ def getObjects(graph):
     """
     project_name = graph.getProject().name
     graphObject = {'nodes': [], 'variables': [], 'groups': []}
+    # test if the graph is a template or not
     if graph.path[-1] == '*template*':
         pid = db[project_name].find_one({'code': 'GraphTemplate', 'name': graph.getName(), 'parent': graph.pattern.uuid},
                                         {'_id': 1})['_id']
-        g = db[project_name].find_one({'code': 'Graph', 'name': graph.getName(), 'parent': pid}, {'template_name': 1})
+        g = db[project_name].find_one({'code': 'Graph', 'name': graph.getName(), 'parent': pid}, {'template_uuid': 1})
+    # test if the graph object contains a uuid
     elif graph.uuid:
-        g = db[project_name].find_one({'code': 'Graph', '_id': graph.uuid}, {'template_name': 1})
+        g = db[project_name].find_one({'code': 'Graph', '_id': graph.uuid}, {'template_uuid': 1})
     else:
         g = db[project_name].find_one({'code': 'Graph', 'name': graph.getName(), 'path': ':'.join(graph.path),
                                        'parent': graph.pattern.uuid}, {'template_name': 1, 'template_uuid': 1})
 
     if g is None:
         return None
+    # if template is not create in graph
     if 'template_uuid' not in g.keys():
-        g['template_uuid'] = getTemplateUuidFromName(graph.pattern, g['template_name'])
+        return None
     graphObject['uuid'] = g['_id']
     graphObject['template_uuid'] = g['template_uuid']
     graphObject['variables'] = []
