@@ -3,6 +3,7 @@ import uuid
 import json
 import os
 import time
+import codecs
 
 USER = os.getenv('USER')
 if not USER:
@@ -18,7 +19,7 @@ def connect(name=None, user=None, pwd=None):
         localSettingsFile = os.path.join(home, 'mangrove1.0', 'settings.info')
         name, user, pwd = '', '', ''
         if os.path.exists(localSettingsFile):
-            with open(localSettingsFile) as fid:
+            with codecs.open(localSettingsFile, encoding='utf8') as fid:
                 dic = json.load(fid)
                 choosen_wrapper = dic['wrapper']['current']
                 name = dic['wrapper'][choosen_wrapper]['host']
@@ -56,10 +57,10 @@ def lock_file(path):
     """
     wait_lock_file(path)
     lock_path = path + '_lock'
-    with open(lock_path, 'w') as fid:
+    with codecs.open(lock_path, 'w', encoding='utf8') as fid:
         fid.write(USER)
     time.sleep(.1)
-    with open(lock_path) as fid:
+    with codecs.open(lock_path, encoding='utf8') as fid:
         u = fid.read()
     if u == USER:
         return True
@@ -150,14 +151,14 @@ def lockProject(project, user):
         str: same user name if lock was empty, else lock value.
         """
     lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     lock = root[project.getName()]['lock']
 
     if lock in ['', user]:
         root[project.getName()]['lock'] = user
-        with open(projects_file_path, 'w') as fid:
-            fid.write(json.dumps(root, sort_keys=True, indent=4))
+        with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+            fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
         unlock_file(projects_file_path)
         return user
     unlock_file(projects_file_path)
@@ -167,12 +168,12 @@ def lockProject(project, user):
 def unlockProject(project):
     """Set project lock property to empty."""
     lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     if project.getName() in root:
         root[project.getName()]['lock'] = ''
-    with open(projects_file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(projects_file_path)
 
 
@@ -192,7 +193,7 @@ def getType(project_name, name=None, uuid=None):
         return None
 
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     gt = None
     if uuid:
@@ -265,7 +266,7 @@ def getHud(project_name, name=None, uuid=None):
         return None
 
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     gt = None
     if uuid:
@@ -276,8 +277,7 @@ def getHud(project_name, name=None, uuid=None):
                 gt = t
                 break
 
-    node_type = mgvApi.MgvHud(uuid=gt['uuid'], name=gt['name'], event=gt['event'],
-                                  script=gt['script'])
+    node_type = mgvApi.MgvHud(uuid=gt['uuid'], name=gt['name'], event=gt['event'], script=gt['script'])
 
     return node_type
 
@@ -298,7 +298,7 @@ def getBatchScript(project_name, name=None, uuid=None):
         return None
 
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     gt = None
     if uuid:
@@ -326,7 +326,7 @@ def getTypes(projectName):
     import mgvApi
     types = []
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     if projectName not in root.keys():
         return []
@@ -381,7 +381,7 @@ def getProject(projectName):
     wait_lock_file(projects_file_path)
     if not projects_file_path:
         return None
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     if projectName not in root.keys():
         return None
@@ -449,10 +449,10 @@ def getProjectNames():
     if not os.path.exists(projects_file_path):
         if not os.path.exists(os.path.dirname(projects_file_path)):
             os.makedirs(os.path.dirname(projects_file_path))
-        with open(projects_file_path, 'w') as fid:
+        with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
             fid.write('{}')
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     return list(root.keys())
 
@@ -471,7 +471,7 @@ def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
     """
     wait_lock_file(projects_file_path)
     # retourne une liste d'elemets de type: [patternName,key0,..,keyN,shot_name]
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     p = getByUuid(root, pattern.uuid)
     if with_node_named is None and with_type_named is None:
@@ -481,7 +481,7 @@ def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
     for x in p['graphs']:
         keys = x.split(':')
         graph_file_path = os.path.join(pattern.convertPath(keys), pattern.convertGraphName(keys)) + '.mgv'
-        with open(graph_file_path) as fid:
+        with codecs.open(graph_file_path, encoding='utf8') as fid:
             root = json.load(fid)
         found = False
         if with_node_named:
@@ -509,16 +509,17 @@ def getGraphInfo(pattern, keys):
         dict: a dictionary with a uuid value and a template_name value.
     """
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     pat = [x for x in root[pattern.project.name]['patterns'] if x['name'] == pattern.name][0]
     gr = [x for x in pat['graphs'] if x == ':'.join(keys)]
     if not len(gr):
         return {'template_name': ''}
-    gr = gr[0]
     file_path = os.path.join(pattern.convertPath(keys), pattern.convertGraphName(keys) + '.mgv')
+    if not os.path.exists(file_path):
+        return {'template_name': ''}
     wait_lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
 
     return {'code': 'Graph', 'uuid': root['uuid'], 'template_name': root['template_name']}
@@ -529,7 +530,7 @@ def getGraphVars(pattern, keys):
     if not os.path.exists(file_path):
         return []
     wait_lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     return root['variables']
 
@@ -537,25 +538,25 @@ def getGraphVars(pattern, keys):
 def setGraphVar(pattern, keys, name, newname=None, value=None, active=None, delete=False):
     file_path = os.path.join(pattern.convertPath(keys), pattern.convertGraphName(keys) + '.mgv')
     lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     if name in [x['name'] for x in root['variables']]:
-        v = [x['name'] for x in root['variables'] if x['name'] == name][0]
+        v = [x for x in root['variables'] if x['name'] == name][0]
         if delete:
-            root['variables'].remove(x)
+            root['variables'].remove(v)
         if value is not None:
-            x['value'] = value
+            v['value'] = value
         if active is not None:
-            x['active'] = active
+            v['active'] = active
         if newname is not None:
-            x['name'] = newname
+            v['name'] = newname
     else:
         newname = name if newname is None else newname
         value = '' if value is None else value
         active = True if active is None else active
         root['variables'].append({'name': newname, 'value': value, 'active': active})
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
 
 
@@ -570,7 +571,7 @@ def graphExists(pattern, graphpath):
     """
     graphpath = ':'.join(graphpath)
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     p = getByUuid(root, pattern.uuid)
     for x in p['graphs']:
@@ -600,7 +601,7 @@ def getObjects(graph):
         file_path = graph.getFilePath()
     if os.path.exists(file_path):
         wait_lock_file(file_path)
-        with open(file_path) as fid:
+        with codecs.open(file_path, encoding='utf8') as fid:
             root = json.load(fid)
             return root
     else:
@@ -625,13 +626,15 @@ def setNodeAttr(node, **kwargs):
         file_path = getFilePath(node)
 
     lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, uuid)
+    if t is None:
+        return False
     for key in kwargs:
         t[key] = kwargs[key]
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
     return True
 
@@ -652,7 +655,7 @@ def getNodeAttr(node, attr):
         uuid = node.uuid
     file_path = getFilePath(node)
     wait_lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, uuid)
     if attr in t:
@@ -695,12 +698,12 @@ def setDictionary(father, typeDic, name, value):
     """
     file_path = getFilePath(father)
     lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, father.uuid)
     t['parameters'][name] = value
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
 
 
@@ -714,12 +717,12 @@ def delDictionary(father, typeDic, name):
    """
     file_path = getFilePath(father)
     lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, father.uuid)
     del t['parameters'][name]
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
 
 
@@ -750,7 +753,7 @@ def createNode(father, code, **kwargs):
     if code in ['Project', 'Pattern', 'GraphTemplate', 'Template', 'Context', 'Action', 'TypeParameter', 'Type',
                 'TypeVersion', 'TypeFile', 'Hud', 'BatchScript']:
         lock_file(file_path)
-        with open(file_path) as fid:
+        with codecs.open(file_path, encoding='utf8') as fid:
             root = json.load(fid)
         father_element = getByUuid(root, father.uuid) if father else None
         if code == 'Project':
@@ -794,21 +797,21 @@ def createNode(father, code, **kwargs):
             kwargs['nodes'] = []
             kwargs['groups'] = []
             kwargs['variables'] = []
-            with open(file_path, 'w') as fid:
-                fid.write(json.dumps(kwargs, sort_keys=True, indent=4))
+            with codecs.open(file_path, 'w', encoding='utf8') as fid:
+                fid.write(json.dumps(kwargs, sort_keys=True, indent=4, ensure_ascii=False))
             lock_file(projects_file_path)
-            with open(projects_file_path) as fid:
+            with codecs.open(projects_file_path, encoding='utf8') as fid:
                 rootP = json.load(fid)
             if father.code == 'Pattern':
                 p = getByUuid(rootP, father.uuid)
             if '*template*' not in kwargs['path']:
                 p['graphs'].append(kwargs['path'])
-            with open(projects_file_path, 'w') as fid:
-                fid.write(json.dumps(rootP, sort_keys=True, indent=4))
+            with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+                fid.write(json.dumps(rootP, sort_keys=True, indent=4, ensure_ascii=False))
             unlock_file(projects_file_path)
 
         lock_file(file_path)
-        with open(file_path) as fid:
+        with codecs.open(file_path, encoding='utf8') as fid:
             root = json.load(fid)
         father_element = getByUuid(root, father.uuid) if father else None
         if code == 'Node':
@@ -825,8 +828,8 @@ def createNode(father, code, **kwargs):
         if code == 'Variable':
             father_element['variables'].append(kwargs)
 
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
 
     return kwargs['uuid']
@@ -836,36 +839,35 @@ def deleteNode(node):
     """Delete an object in the database and all its hierarchy."""
     file_path = getFilePath(node)
     lock_file(file_path)
-    with open(file_path) as fid:
+    with codecs.open(file_path, encoding='utf8') as fid:
         root = json.load(fid)
     removeByUuid(root, node.uuid)
-    with open(file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(file_path)
     if node.code == 'Graph' and '*template*' not in node.path:
         lock_file(projects_file_path)
-        with open(projects_file_path) as fid:
+        with codecs.open(projects_file_path, encoding='utf8') as fid:
             rootP = json.load(fid)
         p = getByUuid(rootP, node.pattern.uuid)
         p['graphs'].remove(':'.join(node.path))
-        with open(projects_file_path, 'w') as fid:
-            fid.write(json.dumps(rootP, sort_keys=True, indent=4))
+        with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+            fid.write(json.dumps(rootP, sort_keys=True, indent=4, ensure_ascii=False))
         unlock_file(projects_file_path)
 
 
 def deleteGraph(pattern, keys):
     """Delete a graph in the database and all its hierarchy."""
     lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         rootP = json.load(fid)
     p = getByUuid(rootP, pattern.uuid)
     p['graphs'].remove(':'.join(keys))
-    with open(projects_file_path, 'w') as fid:
-        fid.write(json.dumps(rootP, sort_keys=True, indent=4))
+    with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(rootP, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(projects_file_path)
 
 
-
 def setLockType(type, user):
     """Set the lock property of a type with a user name.
 
@@ -874,12 +876,12 @@ def setLockType(type, user):
         user (str): the user name.
     """
     lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, type.uuid)
     t['lock'] = user
-    with open(projects_file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(projects_file_path)
 
 
@@ -893,7 +895,7 @@ def getLockType(type):
         None: the type has not been found.
     """
     wait_lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     t = getByUuid(root, type.uuid)
     return t['lock']
@@ -903,7 +905,7 @@ def syncProject(project):
     """Copy and replace all the project data, including patterns, contexts and
         templates, to the database."""
     lock_file(projects_file_path)
-    with open(projects_file_path) as fid:
+    with codecs.open(projects_file_path, encoding='utf8') as fid:
         root = json.load(fid)
     # si pas dans la BDD:
     if project.getName() not in root.keys():
@@ -990,6 +992,6 @@ def syncProject(project):
                 t['name'] = template.name
                 t['icon'] = template.icon
 
-    with open(projects_file_path, 'w') as fid:
-        fid.write(json.dumps(root, sort_keys=True, indent=4))
+    with codecs.open(projects_file_path, 'w', encoding='utf8') as fid:
+        fid.write(json.dumps(root, sort_keys=True, indent=4, ensure_ascii=False))
     unlock_file(projects_file_path)
\ No newline at end of file
